.. _meal-api:

Meal
====

This module defines the ``Meal`` class, which represents a complete meal and aggregates data from its components.

.. automodule:: meal_generator.meal
   :members:
   :undoc-members:
   :show-inheritance: